django_auxilium.callback_mail package
=====================================

.. automodule:: django_auxilium.callback_mail
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   django_auxilium.callback_mail.base
   django_auxilium.callback_mail.filebased
   django_auxilium.callback_mail.signals
   django_auxilium.callback_mail.smtp

